/*
 * Copyright (C) 2000-2003 the xine project
 * 
 * This file is part of xine, a unix video player.
 * 
 * xine is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * xine is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
 *
 * $Id: snapshot.h,v 1.7 2003/02/21 16:21:17 f1rmb Exp $
 *
 * Image snapshot related stuff
 *
 */
#ifndef SNAPSHOT_H
#define SNAPSHOT_H

typedef void (*snapshot_messenger_t)(void *data, char *message);

void create_snapshot (const char *mrl, snapshot_messenger_t error_mcb, 
		      snapshot_messenger_t info_mcb, void *mcb_data);

#endif
